!function(){"use strict";var e;e=function(){"undefined"!=typeof mermaid&&function(a){for(var t=document.querySelectorAll("pre.".concat(a)),e=function(e){var d=t[e],i=document.createElement("div");i.style.visibility="hidden",i.style.width="100%",i.style.minWidth="100%",i.style.fontSize="16px",d.parentNode.appendChild(i),mermaid.mermaidAPI.render("_mermaind_".concat(e),function(e){for(var t="",n=0;n<e.childNodes.length;n++){var d=e.childNodes[n];if("code"===d.tagName.toLowerCase())for(var i=0;i<d.childNodes.length;i++){var a=d.childNodes[i];if("#text"===a.nodeName&&!/^\s*$/.test(a.nodeValue)){t=a.nodeValue;break}}}return t}(d),function(e){var t=document.createElement("div");t.className=a,t.innerHTML=e;var n=t.childNodes[0];!n.hasAttribute("height")&&n.hasAttribute("width")&&n.setAttribute("height",i.childNodes[0].getBoundingClientRect().height),d.parentNode.insertBefore(t,d),d.parentNode.removeChild(d)},i)},n=0;n<t.length;n++)e(n)}("mermaid")},document.addEventListener?(document.addEventListener("DOMContentLoaded",e),document.addEventListener("DOMContentSwitch",e)):document.attachEvent("onreadystatechange",function(){"interactive"===document.readyState&&e()})}();